import matplotlib.pyplot as plt
from scipy.integrate import quad
from scipy.special import gamma
import numpy as np
from pynverse import inversefunc
import warnings
warnings.filterwarnings("ignore") # :-)


plt.rc("font", size=12)

def fun(y, n):
	INT = lambda x,y,n: x**(n-1)/(np.exp(x-y)+1)
	return quad(INT, 0, np.inf, (y, n))[0] / gamma(n)

# a)
print("F_3/2(0) = {0:.4f}".format(fun(0, 3/2)))

# b)
inverse = inversefunc(fun, args=(3/2))
for X in [80, 10, 0.1]:
	print("\mu_{0} = {1:.4f}".format(X, inverse(X)))

#c)
def N(e, nu_x):
	return (np.exp(e-nu_x) + 1)**(-1)

E = np.linspace(-50, 50, 1000)
for X in [100, 1.0, 0.01]:
	plt.plot(E, N(E, inverse(X)), label="$x\,=\,${0} $\Rightarrow$ $\mu_x\,=\,${1:.3f}".format(X, inverse(X)))
plt.xlabel("$\epsilon$")
plt.ylabel("$N$")
plt.legend(loc=(0.03,0.15))
plt.show()
