import matplotlib.pyplot as plt
import numpy as np


plt.rc('font', size=12)

N = [1e1, 1e2, 1e4]
dE = np.linspace(-1, 1, 201)
Gamma = [[] for i in N]
dGamma = [[] for i in N]

def count_gamma(e, N):
	return ((1-e) * (1+e))**(3/2*N)

for n in range(len(N)):
	for e in dE:
		Gamma[n].append(count_gamma(e, N[n]))

plt.figure(figsize=(8,6))
plt.title("Počet mikrostavů v závislosti na fluktuaci energie")
for i in range(len(N)):
	plt.plot(dE, Gamma[i], label="{0} částic".format(int(N[i])))
plt.xlabel("dE $\left[ \\frac{h^2}{2 \pi m} \\right]$")
plt.ylabel("$\Gamma$ $\left[ \\frac{V^N}{N! \Gamma(3/2N+1)} \\right]$")
plt.legend()
#plt.show()
plt.savefig("du5_pocet_mikrostavu.png", dpi=150)
plt.close()

N2 = [1e1, 1e2, 1e4, 1e5]
e = 1/100
err = 0
print("Relativní chyba:")
for n in N2:
	for e in dE:
		err += count_gamma(e, n)
	print("{0} částic:".format(int(n)), "{0}".format(1/err))
